#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif
#include "wavpackdialog.h"

#include <qregexp.h>
#include <qcheckbox.h>
#include <qcombobox.h>
#include <qradiobutton.h>
#include <qbuttongroup.h>
#include <qspinbox.h>
#include <qdecspinbox.h>

void wavpackDialog::fromEncodingSwitches( const QString& switches )
{
	QRegExp regExp;

	regExp.setPattern( "(^|[ \\t])-(f|h)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
	{
		encodingModeCheckBox->setChecked( true );
		if ( regExp.cap( 2 ) == "h" )
			encodingModeComboBox->setCurrentItem( 0 );
		else if ( regExp.cap( 2 ) == "f" )
			encodingModeComboBox->setCurrentItem( 2 );
	}
	else
		encodingModeComboBox->setCurrentItem( 1 );

	regExp.setPattern( "(^|[ \\t])-j(0|1)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
	{
		jointStereoCheckBox->setChecked( true );
		if ( regExp.cap( 2 ) == "0" )
			jointStereoComboBox->setCurrentItem( 1 );
		else if ( regExp.cap( 2 ) == "1" )
			jointStereoComboBox->setCurrentItem( 0 );
	}

	regExp.setPattern( "(^|[ \\t])-x(|[1-6])([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
	{
		extraProcessingCheckBox->setChecked( true );
		if ( regExp.cap( 2 ) != "" )
		{
			extraProcessingLevelCheckBox->setChecked( true );
			extraProcessingLevelSpinBox->setValue( regExp.cap( 2 ).toInt() );
		}
	}


	regExp.setPattern( "(^|[ \\t])-b([0-2]?[0-9].[0-9]|[0-9][0-9]+)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
	{
		double val = regExp.cap( 2 ).toDouble();

		hybridButtonGroup->setChecked( true );
		if ( val < 24 )
		{
			bitsPerSampleRadioButton->setChecked( true );
			bitsPerSampleDecSpinBox->setDecValue( val );
		}
		else
		{
			kbitsPerSecondRadioButton->setChecked( true );
			kbitsPerSecondSpinBox->setValue( (int)val );
		}

		regExp.setPattern( "(^|[ \\t])(-c)([ \\t]|$)" );
		if ( regExp.search( switches ) != -1 )
			correctionFileCheckBox->setChecked( true );

		regExp.setPattern( "(^|[ \\t])(-cc)([ \\t]|$)" );
		if ( regExp.search( switches ) != -1 )
			maxHybridCompCheckBox->setChecked( true );

		regExp.setPattern( "(^|[ \\t])-s(|-)(0?\\.[0-9]|1\\.0|1|0)([ \\t]|$)" );
		if ( regExp.search( switches ) != -1 )
		{
			noiseShapingCheckBox->setChecked( true );
			noiseShapingDecSpinBox->setDecValue( regExp.cap( 3 ).toDouble() * (regExp.cap( 2 ) == "" ? 1 : -1) );
		}
	}

	regExp.setPattern( "(^|[ \\t])(-r)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		riffHeaderCheckBox->setChecked( true );

	regExp.setPattern( "(^|[ \\t])(-i)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		ignoreHeaderCheckBox->setChecked( true );

	regExp.setPattern( "(^|[ \\t])(-p)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		practicalFloatCheckBox->setChecked( true );

	regExp.setPattern( "(^|[ \\t])(-a)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		auditionCheckBox->setChecked( true );

	regExp.setPattern( "(^|[ \\t])(-m)([ \\t]|$)" );
	if ( regExp.search( switches ) != -1 )
		md5sumCheckBox->setChecked( true );
}

QString wavpackDialog::toEncodingSwitches()
{
	QString result;

	if ( encodingModeCheckBox->isChecked() )
	{
		if ( encodingModeComboBox->currentItem() == 0 )
			result += "-h";
		else if ( encodingModeComboBox->currentItem() == 2 )
			result += "-f";
	}

	if ( jointStereoCheckBox->isChecked() )
	{
		if ( jointStereoComboBox->currentItem() == 0 )
			result += " -j1";
		else // if ( jointStereoComboBox->currentItem() == 1 )
			result += " -j0";
	}

	if ( extraProcessingCheckBox->isChecked() )
	{
		result += " -x";
		if ( extraProcessingLevelCheckBox->isChecked() )
			result += QString::number( extraProcessingLevelSpinBox->value() );
	}

	if ( hybridButtonGroup->isChecked() )
	{
		if ( bitsPerSampleRadioButton->isChecked() )
			result += " -b" + QString::number( bitsPerSampleDecSpinBox->decValue(), 'f', 1 );
		else // if ( kbitsPerSecondRadioButton->isChecked() )
			result += " -b" + QString::number( kbitsPerSecondSpinBox->value() );

		if ( correctionFileCheckBox->isChecked() )
			result += " -c";

		if ( maxHybridCompCheckBox->isChecked() )
			result += " -cc";

		if ( noiseShapingCheckBox->isChecked() )
			result += " -s" + QString::number( noiseShapingDecSpinBox->decValue(), 'f', 1 );
	}

	if ( riffHeaderCheckBox->isChecked() )
		result += " -r";

	if ( ignoreHeaderCheckBox->isChecked() )
		result += " -i";

	if ( practicalFloatCheckBox->isChecked() )
		result += " -p";

	if ( auditionCheckBox->isChecked() )
		result += " -a";

	if ( md5sumCheckBox->isChecked() )
		result += " -m";

	return result;
}
