#ifndef _TRANSKODEFILETYPERESOLVER_H_
#define _TRANSKODEFILETYPERESOLVER_H_

/***************************************************************************
 *   Copyright (C) 2005 by Sergio Pistone                                  *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <commondefs.h>

#include <fileref.h>
#include <tag.h>

#include <audioproperties.h>
#include <mpegfile.h>
#include <mpcfile.h>
#include <flacfile.h>
#include <oggfile.h>
#include <oggflacfile.h>
#include <vorbisfile.h>

/**
 * NOTE: only one instance of this class should be added as a file type resolver.
 * That implies that all threads should use the same instance and that such instance
 * has to be protected by a mutex.
 */

class TransKodeFileTypeResolver: TagLib::FileRef::FileTypeResolver
{
	public:
		TransKodeFileTypeResolver( bool add=false )
		{
			if ( add )
				TagLib::FileRef::addFileTypeResolver( this );
		}

		void setEncodeType( EncodeType::TEncodeType encodeType )
		{
			m_encodeType = encodeType;
		}

	private:
		virtual TagLib::File* createFile(
			const char* fileName,
			bool readAudioProperties = true,
			TagLib::AudioProperties::ReadStyle audioPropertiesStyle = TagLib::AudioProperties::Average) const
		{
			switch ( m_encodeType )
			{
				case EncodeType::ttaenc:
				case EncodeType::lame:		return new TagLib::MPEG::File( fileName, readAudioProperties, audioPropertiesStyle );
				case EncodeType::mac:
				case EncodeType::wavpack:
				case EncodeType::mppenc:	return new TagLib::MPC::File( fileName, readAudioProperties, audioPropertiesStyle );
				case EncodeType::oggenc:	return new TagLib::Ogg::Vorbis::File( fileName, readAudioProperties, audioPropertiesStyle );
				case EncodeType::flac:		return new TagLib::FLAC::File( fileName, readAudioProperties, audioPropertiesStyle );
				default:					break;
			}

			//if ( encodeType == EncodeType::UNKNOWN ) // used when reading
			//{
				QFileInfo fileInfo( fileName );
				QString ext = fileInfo.extension().lower();

				if ( ext == "flc" || ext == "flac" )
					new TagLib::FLAC::File( fileName, readAudioProperties, audioPropertiesStyle );
				else if ( ext == "ogg" )
					return new TagLib::Ogg::Vorbis::File( fileName, readAudioProperties, audioPropertiesStyle );
				//else if ( ext == "spx" || ext == "speex" )
				//else if ( ext == "mp4" || ext == "m4a" || ext == "aac" )
				else if ( ext == "ape" || ext == "mac" || ext == "wv" || ext == "mpc" || ext == "mpp" || ext == "mp+" )
					return new TagLib::MPC::File( fileName, readAudioProperties, audioPropertiesStyle );
				else if ( ext == "mp3" || ext == "tta" )
					return new TagLib::MPEG::File( fileName, readAudioProperties, audioPropertiesStyle );
			//}

			return 0;
		}

		EncodeType::TEncodeType m_encodeType;
};

#endif
